class User:
    def __init__(self, json_dict):
        self.id = json_dict.get('id')
        self.first_name = json_dict.get('first_name')
        self.last_name = json_dict.get('last_name')
        self.deactivated = json_dict.get('deactivated')
        self.is_closed = json_dict.get('is_closed')
        self.can_access_closed = json_dict.get('can_access_closed')
        self.about = json_dict.get('about')
        self.activities = json_dict.get('activities')
        self.bdate = json_dict.get('bdate')
        self.blacklisted = json_dict.get('blacklisted')
        self.blacklisted_by_me = json_dict.get('blacklisted_by_me')
        self.books = json_dict.get('books')
        self.can_post = json_dict.get('can_post')
        self.can_see_all_posts = json_dict.get('can_see_all_posts')
        self.can_see_audio = json_dict.get('can_see_audio')
        self.can_send_friend_request = json_dict.get('can_send_friend_request')
        self.can_write_private_message = json_dict.get('can_write_private_message')
        self.career = json_dict.get('career')
        self.city = json_dict.get('city')
        self.common_count = json_dict.get('common_count')
        self.connections = json_dict.get('connections')
        self.contacts = json_dict.get('contacts')
        self.counters = json_dict.get('counters')
        self.country = json_dict.get('country')
        self.crop_photo = json_dict.get('crop_photo')
        self.domain = json_dict.get('domain')
        self.education = json_dict.get('education')
        self.exports = json_dict.get('exports')
        self.followers_count = json_dict.get('followers_count')
        self.friend_status = json_dict.get('friend_status')
        self.games = json_dict.get('games')
        self.has_mobile = json_dict.get('has_mobile')
        self.has_photo = json_dict.get('has_photo')
        self.home_town = json_dict.get('home_town')
        self.interests = json_dict.get('interests')
        self.is_friend = json_dict.get('is_friend')
        self.is_hidden_from_feed = json_dict.get('is_hidden_from_feed')
        self.last_seen = json_dict.get('last_seen')
        self.lists = json_dict.get('lists')
        self.maiden_name = json_dict.get('maiden_name')
        self.military = json_dict.get('military')
        self.movies = json_dict.get('movies')
        self.music = json_dict.get('music')
        self.nickname = json_dict.get('nickname')
        self.occupation = json_dict.get('occupation')
        self.online = json_dict.get('online')
        self.personal = json_dict.get('personal')
        self.photo_50 = json_dict.get('photo_50')
        self.photo_100 = json_dict.get('photo_100')
        self.photo_200_orig = json_dict.get('photo_200_orig')
        self.photo_200 = json_dict.get('photo_200')
        self.photo_400_orig = json_dict.get('photo_400_orig')
        self.photo_id = json_dict.get('photo_id')
        self.photo_max = json_dict.get('photo_max')
        self.photo_max_orig = json_dict.get('photo_max_orig')
        self.quotes = json_dict.get('quotes')
        self.relatives = json_dict.get('relatives')
        self.relation = json_dict.get('relation')
        self.schools = json_dict.get('schools')
        self.screen_name = json_dict.get('screen_name')
        self.sex = json_dict.get('sex')
        self.site = json_dict.get('site')
        self.status = json_dict.get('status')
        self.timezone = json_dict.get('timezone')
        self.trending = json_dict.get('trending')
        self.tv = json_dict.get('tv')
        self.universities = json_dict.get('universities')
        self.verified = json_dict.get('verified')
        self.wall_default = json_dict.get('wall_default')

class Media:
    def __init__(self):
        pass